# InChat API

A Python library for interacting with the InChat API.

## Installation

```bash
pip install Inchatvx

"""
Usage : 


from APIX import chatinvx

api = InChatAPI(device_id="", new_device_id="", token="")
user_info = api.get_user_info(uid=12345, token="")
print(user_info)


"""
